| chf_df | R Documentation |
Activity data from a study of congestive heart failure (CHF) patients. Data were originally presented in Huang et al. (2019); these data are publicly available, with download information in the paper.
chf_df
A tibble with 329 rows and 8 columns:
(numeric) Subject identifier.
(character) "Male" or "Female".
(numeric) Age in years.
(numeric) Body mass index.
(numeric) Week of cardiac event.
(character) Type of cardiac event.
(ordered factor) Day of the week (Mon < Tue < ... < Sun).
(tfd_reg) Minute-by-minute activity counts over
a 24-hour period (arg domain 1–1440).
Data are from a study of physical activity in CHF patients conducted by Huang et al. The original data are publicly available; see the paper for download details.
Huang, L., Bai, J., Ivanescu, A., Harris, T., Maurer, M., Green, P., and Zipunnikov, V. (2019). Multilevel Matrix-Variate Analysis and its Application to Accelerometry-Measured Physical Activity in Clinical Populations. Journal of the American Statistical Association, 114(526), 553–564. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/01621459.2018.1482750")}
dti_df for another example dataset,
vignette("x04_Visualization", package = "tidyfun") for usage examples.
Other tidyfun datasets:
dti_df
chf_df
library(ggplot2)
chf_df |>
dplyr::filter(id %in% 1:5) |>
gglasagna(activity, order_by = mean)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.