| dti_df | R Documentation |
Fractional anisotropy (FA) tract profiles for the corpus callosum (cca)
and the right corticospinal tract (rcst) from a diffusion tensor imaging
(DTI) study of multiple sclerosis patients and healthy controls.
The original data in refund::DTI include additional variables (pasat,
Nscans, visit.time) that were not carried over here.
dti_df
A tibble with 382 rows and 6 columns:
(numeric) Subject identifier.
(integer) Visit number.
(factor) "male" or "female".
(factor) "control" or "MS" (multiple sclerosis status).
(tfd_irreg) FA tract profiles for the corpus callosum
(up to 93 evaluation points, domain 0–1).
(tfd_irreg) FA tract profiles for the right corticospinal
tract (up to 55 evaluation points, domain 0–1).
If you use this data as an example in written work, please include the following acknowledgment: "The MRI/DTI data were collected at Johns Hopkins University and the Kennedy-Krieger Institute."
Data are from the Johns Hopkins University and the Kennedy-Krieger Institute. Also available in a different format as refund::DTI.
Goldsmith, J., Bobb, J., Crainiceanu, C., Caffo, B., and Reich, D. (2011). Penalized Functional Regression. Journal of Computational and Graphical Statistics, 20(4), 830–851. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1198/jcgs.2010.10007")}
Goldsmith, J., Crainiceanu, C., Caffo, B., and Reich, D. (2012). Longitudinal Penalized Functional Regression for Cognitive Outcomes on Neuronal Tract Measurements. Journal of the Royal Statistical Society: Series C, 61(3), 453–469. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/j.1467-9876.2011.01031.x")}
chf_df for another example dataset,
vignette("x04_Visualization", package = "tidyfun") for usage examples.
Other tidyfun datasets:
chf_df
dti_df
library(ggplot2)
dti_df |>
dplyr::filter(visit == 1) |>
tf_ggplot(aes(tf = cca, color = case)) +
geom_line(alpha = 0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.