Plots a miniature glyph / sparkline for each entry of a tf-object.
(Capellini are tiny spaghetti – angel hair pasta.) Aesthetics x and y
specify the location of the glyphs, the tf aesthetic defines their shapes.
The aliases geom_cappelini, geom_cappellini, and geom_capelini are
also accepted.
Usage
stat_capellini(
mapping = NULL,
data = NULL,
geom = "capellini",
position = "identity",
na.rm = TRUE,
show.legend = NA,
inherit.aes = TRUE,
arg = NULL,
add_lines = FALSE,
add_boxes = TRUE,
width = NULL,
height = NULL,
...
)
geom_capellini(
mapping = NULL,
data = NULL,
stat = "capellini",
position = "identity",
...,
na.rm = TRUE,
show.legend = NA,
inherit.aes = TRUE,
arg = NULL,
add_lines = TRUE,
add_boxes = TRUE,
width = NULL,
height = NULL,
box.colour = "#0000001A",
box.linetype = 1,
box.fill = NA,
box.linewidth = 0.1,
box.alpha = 0.1,
line.colour = "black",
line.linetype = 2,
line.linewidth = 0.3,
line.alpha = 0.5
)Arguments
- mapping
Set of aesthetic mappings created by
aes(). If specified andinherit.aes = TRUE(the default), it is combined with the default mapping at the top level of the plot. You must supplymappingif there is no plot mapping.- data
The data to be displayed in this layer. There are three options:
If
NULL, the default, the data is inherited from the plot data as specified in the call toggplot().A
data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. Seefortify()for which variables will be created.A
functionwill be called with a single argument, the plot data. The return value must be adata.frame, and will be used as the layer data. Afunctioncan be created from aformula(e.g.~ head(.x, 10)).- geom
The geometric object to use to display the data for this layer. When using a
stat_*()function to construct a layer, thegeomargument can be used to override the default coupling between stats and geoms. Thegeomargument accepts the following:A
Geomggproto subclass, for exampleGeomPoint.A string naming the geom. To give the geom as a string, strip the function name of the
geom_prefix. For example, to usegeom_point(), give the geom as"point".For more information and other ways to specify the geom, see the layer geom documentation.
- position
A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The
positionargument accepts the following:The result of calling a position function, such as
position_jitter(). This method allows for passing extra arguments to the position.A string naming the position adjustment. To give the position as a string, strip the function name of the
position_prefix. For example, to useposition_jitter(), give the position as"jitter".For more information and other ways to specify the position, see the layer position documentation.
- na.rm
remove NAs? defaults to
TRUE- show.legend
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.FALSEnever includes, andTRUEalways includes. It can also be a named logical vector to finely select the aesthetics to display. To include legend keys for all levels, even when no data exists, useTRUE. IfNA, all levels are shown in legend, but unobserved levels are omitted.- inherit.aes
If
FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g.annotation_borders().- arg
where to evaluate
tf; defaults to the object's default evaluation grid.- add_lines
should a reference line in the middle of the range of the functions' values be added to each glyph? defaults to TRUE
- add_boxes
should a box be added to frame each glyph? defaults to TRUE
- width
the width of the glyphs. Defaults to 2/3 of the
ggplot2::resolution()of the variable for thex-aesthetic, this will be too small if any values are close together.- height
the height of the glyphs. Defaults to 2/3 of the
ggplot2::resolution()of the variable for they-aesthetic, this will be too small if any values are close together.- ...
Other arguments passed on to
layer()'sparamsargument. These arguments broadly fall into one of 4 categories below. Notably, further arguments to thepositionargument, or aesthetics that are required can not be passed through.... Unknown arguments that are not part of the 4 categories below are ignored.Static aesthetics that are not mapped to a scale, but are at a fixed value and apply to the layer as a whole. For example,
colour = "red"orlinewidth = 3. The geom's documentation has an Aesthetics section that lists the available options. The 'required' aesthetics cannot be passed on to theparams. Please note that while passing unmapped aesthetics as vectors is technically possible, the order and required length is not guaranteed to be parallel to the input data.When constructing a layer using a
stat_*()function, the...argument can be used to pass on parameters to thegeompart of the layer. An example of this isstat_density(geom = "area", outline.type = "both"). The geom's documentation lists which parameters it can accept.Inversely, when constructing a layer using a
geom_*()function, the...argument can be used to pass on parameters to thestatpart of the layer. An example of this isgeom_area(stat = "density", adjust = 0.5). The stat's documentation lists which parameters it can accept.The
key_glyphargument oflayer()may also be passed on through.... This can be one of the functions described as key glyphs, to change the display of the layer in the legend.
- stat
the stat to use; defaults to
"capellini".- box.colour
aesthetic property of the box
- box.linetype
aesthetic property of the box
- box.fill
aesthetic property of the box
- box.linewidth
aesthetic property of the box
- box.alpha
aesthetic property of the box
- line.colour
aesthetic property of the reference line
- line.linetype
aesthetic property of the reference line
- line.linewidth
aesthetic property of the reference line
- line.alpha
aesthetic property of the reference line
Value
A ggplot2::layer() object for use in a ggplot.
See also
Other tidyfun visualization:
autoplot.tf(),
gglasagna(),
ggspaghetti
Examples
library(ggplot2)
weather <- fda::CanadianWeather
canada <- data.frame(
place = weather$place,
region = weather$region,
lat = weather$coordinates[, 1],
lon = -weather$coordinates[, 2],
region = weather$region
)
canada$temp <- tfd(t(weather$dailyAv[, , 1]), arg = 1:365)
canada$precipl10 <- tfd(t(weather$dailyAv[, , 3]), arg = 1:365) |> tf_smooth()
#> Using `f = 0.15` as smoother span for `lowess()`.
canada_map <-
data.frame(maps::map("world", "Canada", plot = FALSE)[c("x", "y")])
# map of canada with annual temperature averages in red, precipitation in blue:
ggplot(canada, aes(x = lon, y = lat)) +
geom_capellini(aes(tf = precipl10), width = 3, height = 5, colour = "blue") +
geom_capellini(aes(tf = temp), width = 3, height = 5, colour = "red") +
geom_path(data = canada_map, aes(x = x, y = y), alpha = 0.1) +
coord_quickmap()
ggplot(canada, aes(x = lon, y = lat, colour = region)) +
geom_capellini(aes(tf = precipl10),
width = 5, height = 3,
line.linetype = 1, box.fill = "white", box.alpha = 0.5, box.colour = NA
)