parse_tf_aesthetics: Parse aesthetic mappings to separate tf and regular...

View source: R/tf-ggplot.R

parse_tf_aestheticsR Documentation

Parse aesthetic mappings to separate tf and regular aesthetics

Description

Parse aesthetic mappings to separate tf and regular aesthetics

Usage

parse_tf_aesthetics(mapping, data = NULL)

Arguments

mapping

An aesthetic mapping created with ggplot2::aes().

data

Data frame to evaluate expressions against.

Value

A list with components tf_aes, scalar_tf_aes, and regular_aes.

Examples

parse_tf_aesthetics(ggplot2::aes(tf = f, color = group))
parse_tf_aesthetics(ggplot2::aes(x = x, y = y))

tidyfun documentation built on April 24, 2026, 5:06 p.m.