| tf_nest | R Documentation |
tf-objectsSimilar in spirit to tidyr::nest(). This turns tables in "long" format,
where one column (.id) defines the unit of observation, one column (.arg)
defines the evaluation grids of the functional observations, and other columns (...)
define the values of the functions at those points into a (much shorter) table containing
tfd-objects. All other variables are checked for constancy over .id and
appended as well.
tf_nest(
data,
...,
.id = "id",
.arg = "arg",
domain = NULL,
evaluator = "tf_approx_linear"
)
data |
a data frame |
... |
A selection of columns. If empty, all variables except the
|
.id |
the (bare or quoted) name of the column defining the different observations. Defaults to "id". |
.arg |
the (bare or quoted) name of the column defining the |
domain |
optional. Range of possible |
evaluator |
optional. A function accepting arguments x, arg, evaluations. See |
domain and evaluator can be specified as lists or vectors
if you are nesting multiple functional data columns with different properties.
Because this interface captures evaluator names as text, supply the evaluator
as a string rather than a bare function name.
a data frame with (at least) .id and tfd columns
tf::tfd() for details on domain and evaluator.
Other tidyfun data wrangling functions:
tf_evaluate.data.frame(),
tf_gather(),
tf_spread(),
tf_unnest()
d <- dplyr::tibble(id = rep(1:3, each = 5), arg = rep(1:5, 3), value = rnorm(15))
tf_nest(d, .id = id, .arg = arg)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.