Similar in spirit to tidyr::nest(). This turns tables in "long" format,
where one column (.id) defines the unit of observation, one column (.arg)
defines the evaluation grids of the functional observations, and other columns (...)
define the values of the functions at those points into a (much shorter) table containing
tfd-objects. All other variables are checked for constancy over .id and
appended as well.
Arguments
- data
a data frame
- ...
A selection of columns. If empty, all variables except the
.idand.argcolumns are selected. You can supply bare variable names, select all variables betweenxandzwithx:z, excludeywith-y. For more options, see thedplyr::select()documentation.- .id
the (bare or quoted) name of the column defining the different observations. Defaults to "id".
- .arg
the (bare or quoted) name of the column defining the
arg-values of the observed functions. Defaults to "arg".- domain
optional. Range of possible
arg-values. Seetf::tfd()for details.- evaluator
optional. A function accepting arguments x, arg, evaluations. See
tf::tfd()for details.
Details
domain and evaluator can be specified as lists or vectors
if you are nesting multiple functional data columns with different properties.
Because this interface captures evaluator names as text, supply the evaluator
as a string rather than a bare function name.
See also
tf::tfd() for details on domain and evaluator.
Other tidyfun data wrangling functions:
tf_evaluate.data.frame(),
tf_gather(),
tf_spread(),
tf_unnest()