tidyfun: Tidy Functional Data Wrangling and Visualization
Source:R/tidyfun-package.R
tidyfun-package.Rdtidyfun makes data wrangling and exploratory analysis for functional data
in R easier.
The tf package defines the core functional data classes and methods.
tidyfun builds on those objects with:
data-frame workflows for functional data:
tf_gather()etc.graphics helpers for
tfobjects and tidy functional data frames:geom_spaghetti(),gglasagna()documentation and examples that show how to use
tfobjects in tidy workflows
Start withvignette(package = "tidyfun")for the article index.
Author
Maintainer: Fabian Scheipl fabian.scheipl@googlemail.com (ORCID) [copyright holder]
Authors:
Jeff Goldsmith
Julia Wrobel (ORCID)
Other contributors:
Maximilian Mücke (ORCID) [contributor]